#
# Some constant values:  URNs for implementations of CitableAnnotations.
#
"""URN for index of all personal names to occurrences in HMT texts."""
PERSNAME_INDEX_URN = Cite2Urn("urn:cite2:hmt:persnameindex.v1:all")

"""URN for index of all place names to occurrences in HMT texts."""
PLACENAME_INDEX_URN = Cite2Urn("urn:cite2:hmt:placenameindex.v1:all")

"""URN for index of all ethnic group names to occurrences in HMT texts."""
ETHNICGROUP_INDEX_URN = Cite2Urn("urn:cite2:hmt:ethnicgroupindex.v1:all")

"""URN for index of scholia to Iliad."""
COMMENTARY_URN = Cite2Urn("urn:cite2:hmt:commentary.v1:all")

"""URN for index of pages of Venetus A manuscript to rectangular regions on images."""
PAGEROI_URN = Cite2Urn("urn:cite2:hmt:commentary.v1:all")


# This should be generated by a better implementation
# of `cex` for these types.
"""Data model and relation set declaration for scholia-passage indexing."""
COMMENTARY_HEADER = """

#!datamodels
Collection|Model|Label|Description
$(COMMENTARY_URN)|$(CitableAnnotations.COMMENTARY_MODEL)|Relation of commentary to text passages commented on.

#!citerelationset
urn|$(COMMENTARY_URN)
label|Index of scholia to *Iliad* passages they comment on

scholion|iliad
"""

PERSNAME_INDEX_HEADER = """
#!datamodels
Collection|Model|Label|Description
$(PERSNAME_INDEX_URN)|$(CitableAnnotations.NAMED_ENTITY_INDEX_MODEL)|Index of text passages to occurrences of personal names


#!citerelationset
urn|$(PERSNAME_INDEX_URN)
label|Index of text passages to occurrences of personal names
passage|person
"""



PLACENAME_INDEX_HEADER = """
#!datamodels
Collection|Model|Label|Description
$(PLACENAME_INDEX_URN)|$(CitableAnnotations.NAMED_ENTITY_INDEX_MODEL)|Index of text passages to occurrences of place names


#!citerelationset
urn|$(PLACENAME_INDEX_URN)
label|Index of text passages to occurrences of place names
passage|place
"""



ETHNICGROUP_INDEX_HEADER = """
#!datamodels
Collection|Model|Label|Description
$(ETHNICGROUP_INDEX_URN)|$(CitableAnnotations.NAMED_ENTITY_INDEX_MODEL)|Index of text passages to occurrences of names of ethnic groups


#!citerelationset
urn|$(ETHNICGROUP_INDEX_URN)
label|Index of text passages to occurrences of names of ethnic groups
passage|ethnic
"""

#
# Some constant values:  URNs for data models of collections and indices
#
"""URN for model of a collection of records indexing text passages to chunks (paragraphs)."""
PARAGRAPH_MODEL = Cite2Urn("urn:cite2:hmt:datamodels.v1:paragraphing")
PAGE_IMAGE_ZONE_MODEL = Cite2Urn("urn:cite2:hmt:datamodels.v1:pageroi")

#
# Some constant values:  URNs for collections
#
"""URN for a `DSECollection` with all HMT project DSE records."""
DSE_URN = Cite2Urn("urn:cite2:hmt:hmtdse.v1:all")

"""URN for a collection with authority list for HMT place names."""
PLACES_URN = Cite2Urn("urn:cite2:hmt:place.v1:")

"""URN for a collection with authority list for HMT names of persons."""
PERSONS_URN = Cite2Urn("urn:cite2:hmt:pers.v1:")

